Documentation
¶
Index ¶
- func FailedTests(groups []*spec.TestGroup)
- func JUnitReport(groups []*spec.TestGroup, filePath string) error
- func PrintFailedClientTests(group *spec.ClientTestGroup)
- func PrintSummaryForClient(group *spec.ClientTestGroup)
- func Summary(groups []*spec.TestGroup)
- func SummaryForClient(group *spec.ClientTestGroup) string
- type JUnitError
- type JUnitFailure
- type JUnitSkipped
- type JUnitTestCase
- type JUnitTestReport
- type JUnitTestSuite
- type WebReportServer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FailedTests ¶
FailedTests outputs the report of failed tests.
func JUnitReport ¶
JUnitReport writes a file which contains the JUnit report generated by test result of h2spec.
func PrintFailedClientTests ¶
func PrintFailedClientTests(group *spec.ClientTestGroup)
FailedTests outputs the report of failed tests.
func PrintSummaryForClient ¶
func PrintSummaryForClient(group *spec.ClientTestGroup)
func Summary ¶
Summary outputs the summary of test result that includes the number of passsed, skipped and failed.
func SummaryForClient ¶
func SummaryForClient(group *spec.ClientTestGroup) string
Summary outputs the summary of test result that includes the number of passsed, skipped and failed.
Types ¶
type JUnitError ¶
JUnitSkipped represents the error element of JUnit XML format.
type JUnitFailure ¶
JUnitFailure represents the failure element of JUnit XML format.
type JUnitSkipped ¶
JUnitSkipped represents the skipped element of JUnit XML format.
type JUnitTestCase ¶
type JUnitTestCase struct {
XMLName xml.Name `xml:"testcase"`
Package string `xml:"package,attr"`
ClassName string `xml:"classname,attr"`
Time string `xml:"time,attr"`
Failure *JUnitFailure `xml:"failure"`
Skipped *JUnitSkipped `xml:"skipped"`
Error *JUnitError `xml:"error"`
}
JUnitTestCase represents the testcase element of JUnit XML format.
type JUnitTestReport ¶
type JUnitTestReport struct {
XMLName xml.Name `xml:"testsuites"`
TestSuites []*JUnitTestSuite `xml:"testsuite"`
}
JUnitReport represents the JUnit XML format.
type JUnitTestSuite ¶
type JUnitTestSuite struct {
XMLName xml.Name `xml:"testsuite"`
Name string `xml:"name,attr"`
Package string `xml:"package,attr"`
ID string `xml:"id,attr"`
Tests int `xml:"tests,attr"`
Skipped int `xml:"skipped,attr"`
Failures int `xml:"failures,attr"`
Errors int `xml:"errors,attr"`
TestCases []*JUnitTestCase `xml:"testcase"`
}
JUnitTestSuite represents the testsuite element of JUnit XML format.
type WebReportServer ¶
func NewWebReportServer ¶
func NewWebReportServer(config *config.Config, spec *spec.ClientTestGroup) *WebReportServer
func (*WebReportServer) RunForever ¶
func (server *WebReportServer) RunForever() error